@@ -1,5 +1,5 @@
-from discordup._discord import Discord
-from discordup._distro import findDistroType
+from ._discord import Discord
+from ._distro import findDistroType
 
 def main(install=False):
     distroType = findDistroType()
